#include "common/firmware_options.h"

#include <string>
#include <bitset>

FirmwareOptions::FirmwareOptions()
{
    clear();
}

FirmwareOptions::~FirmwareOptions()
{
}

void FirmwareOptions::clear()
{
    // Dieses Set ist als Merker, welche der Werte vom Gerät gelesen oder in das Gerät geschrieben werden sollen.
    selectedValues.clear();

    _systemFlags = 0xFFFFFFFF;
    _typeExternalReader = 0;
    _optionIOModule = false;
    _optionTBAdaption = false;
    _optionComServer = false;
    _optionTPWrite = false;
    _optionHTTP = false;
    _optionLanguage = false;
    _optionBiokeyUpdate = false;

    _setupOptionsMask = 0x0001;
    _setupOptions = 0xFFFF;

    _payableOptionsMask = 0x03;
    _payableOptions = 0;
}

void FirmwareOptions::setSystemFlags( unsigned int flags )
{
    _systemFlags = flags;
}

unsigned int FirmwareOptions::getSystemFlags( unsigned int mask ) const
{
    return (_systemFlags & mask);
}

unsigned int FirmwareOptions::getSystemFlags() const
{
    return _systemFlags;
}

void FirmwareOptions::setTypeExternalReader( unsigned char type )
{
    _typeExternalReader = type;
}

unsigned char FirmwareOptions::getTypeExternalReader()
{
    return _typeExternalReader;
}

void FirmwareOptions::setOptionIOModule( unsigned char enabled )
{
    _optionIOModule = enabled;
}

unsigned char FirmwareOptions::getOptionIOModule()
{
    return _optionIOModule;
}

void FirmwareOptions::setOptionTBAdaption( unsigned char enabled )
{
    _optionTBAdaption = enabled;
}

unsigned char FirmwareOptions::getOptionTBAdaption()
{
    return _optionTBAdaption;
}

void FirmwareOptions::setOptionComServer( unsigned char enabled )
{
    _optionComServer = enabled;
}

unsigned char FirmwareOptions::getOptionComServer()
{
    return _optionComServer;
}

void FirmwareOptions::setOptionTPWrite( unsigned char enabled )
{
    _optionTPWrite = enabled;
}

unsigned char FirmwareOptions::getOptionTPWrite()
{
    return _optionTPWrite;
}

void FirmwareOptions::setOptionHTTP( unsigned char enabled )
{
    _optionHTTP = enabled;
}

unsigned char FirmwareOptions::getOptionHTTP()
{
    return _optionHTTP;
}

void FirmwareOptions::setOptionLanguage( unsigned char enabled )
{
    _optionLanguage = enabled;
}

unsigned char FirmwareOptions::getOptionLanguage()
{
    return _optionLanguage;
}

void FirmwareOptions::setOptionBiokeyUpdate( unsigned char enabled )
{
    _optionBiokeyUpdate = enabled;
}

unsigned char FirmwareOptions::getOptionBiokeyUpdate()
{
    return _optionBiokeyUpdate;
}

void FirmwareOptions::setSetupOptions( unsigned short mask, unsigned short options )
{
    _setupOptionsMask = mask;
    _setupOptions = options;
}

unsigned short FirmwareOptions::getSetupOptions( unsigned short mask )
{
    return (_setupOptions & mask);
}

unsigned short FirmwareOptions::getSetupOptions()
{
    return _setupOptions;
}

unsigned short FirmwareOptions::getSetupOptionsMask()
{
    return _setupOptionsMask;
}

void FirmwareOptions::setPayableOptions( unsigned char mask, unsigned char options )
{
    _payableOptionsMask = mask;
    _payableOptions = options;
}

bool FirmwareOptions::isPayableOption( FirmwareOptions::EnumPayableOption option )
{
    return (((_payableOptions & _payableOptionsMask) & option) == option);
}

unsigned char FirmwareOptions::getPayableOptions()
{
    return _payableOptions;
}

unsigned char FirmwareOptions::getPayableOptionsMask()
{
    return _payableOptionsMask;
}